@@ -11,5 +11,5 @@ print('=' * 30)
 print('【python-office库】，功能持续更新中')
 print( '全部功能文档：https://www.python-office.com/')
 print('使用有问题 or 提交你的功能需求 or 参与项目开发')
-print('请加入【项目交流群】： https://www.python-office.com/api/img-cdn/python-office.jpg')
+print('请加入【项目交流群】：http://t.cn/A65MiFvH')
 print('=' * 30)
